[sr-dev] git:master: modules: several small doxygen bug fixes

Henning Westerholt henning.westerholt at 1und1.de
Sun Sep 4 22:32:40 CEST 2011


Module: sip-router
Branch: master
Commit: 8d67ed8e92dd0e46490d44e1dcd869b12116e4ec
URL:    http://git.sip-router.org/cgi-bin/gitweb.cgi/sip-router/?a=commit;h=8d67ed8e92dd0e46490d44e1dcd869b12116e4ec

Author: Henning Westerholt <henning.westerholt at 1und1.de>
Committer: Henning Westerholt <henning.westerholt at 1und1.de>
Date:   Sun Sep  4 22:13:23 2011 +0200

modules: several small doxygen bug fixes

---

 modules/db_mysql/km_res.h |    1 -
 modules/db_mysql/km_val.h |    1 -
 modules_k/rr/api.h        |    4 ++--
 modules_k/rr/record.c     |    1 +
 modules_k/rr/rr_cb.c      |    4 ++--
 modules_k/usrloc/dlist.h  |    2 +-
 6 files changed, 6 insertions(+), 7 deletions(-)

diff --git a/modules/db_mysql/km_res.h b/modules/db_mysql/km_res.h
index 39b6d3d..957a961 100644
--- a/modules/db_mysql/km_res.h
+++ b/modules/db_mysql/km_res.h
@@ -25,7 +25,6 @@
 
 /*! \file
  *  \brief DB_MYSQL :: Result related functions
- *  \ref res.c
  *  \ingroup db_mysql
  *  Module: \ref db_mysql
  */
diff --git a/modules/db_mysql/km_val.h b/modules/db_mysql/km_val.h
index c927f28..299f73d 100644
--- a/modules/db_mysql/km_val.h
+++ b/modules/db_mysql/km_val.h
@@ -23,7 +23,6 @@
 
 /*! \file
  *  \brief DB_MYSQL :: Data conversions
- *  \ref val.c
  *  \ingroup db_mysql
  *  Module: \ref db_mysql
  */
diff --git a/modules_k/rr/record.c b/modules_k/rr/record.c
index c68eb93..629c38a 100644
--- a/modules_k/rr/record.c
+++ b/modules_k/rr/record.c
@@ -151,6 +151,7 @@ static inline struct lump *insert_rr_param_lump(struct lump *before,
 * Build a Record-Route header field, allocates new private memory for this.
  * \param _l first lump
  * \param _l2 second lump
+ * \param user user parameter
  * \param tag tag parameter
  * \param params parameter
  * \param _inbound inbound request
diff --git a/modules_k/rr/rr_cb.c b/modules_k/rr/rr_cb.c
index cbf6655..3d81071 100644
--- a/modules_k/rr/rr_cb.c
+++ b/modules_k/rr/rr_cb.c
@@ -86,13 +86,13 @@ int register_rrcb( rr_cb_t f, void *param )
  * \param req SIP request
  * \param rr_param callback list
  */
-void run_rr_callbacks( struct sip_msg *req, str *rr_params )
+void run_rr_callbacks( struct sip_msg *req, str *rr_param )
 {
 	str l_param;
 	struct rr_callback *cbp;
 
 	for ( cbp=rrcb_hl ; cbp ; cbp=cbp->next ) {
-		l_param = *rr_params;
+		l_param = *rr_param;
 		LM_DBG("callback id %d entered with <%.*s>\n",
 			cbp->id , l_param.len,l_param.s);
 		cbp->callback( req, &l_param, cbp->param );
diff --git a/modules_k/usrloc/dlist.h b/modules_k/usrloc/dlist.h
index 0e81cda..851fca6 100644
--- a/modules_k/usrloc/dlist.h
+++ b/modules_k/usrloc/dlist.h
@@ -118,7 +118,7 @@ int synchronize_all_udomains(void);
  * \param part_max maximal part
  * \return 0 on success, positive if buffer size was not sufficient, negative on failure
  */
-int get_all_ucontacts(void *, int, unsigned int,
+int get_all_ucontacts(void *buf, int len, unsigned int flags,
 		unsigned int part_idx, unsigned int part_max);
 
 




More information about the sr-dev mailing list
diff --git a/modules_k/rr/api.h b/modules_k/rr/api.h
index 09c9a4e..d25a13b 100644
--- a/modules_k/rr/api.h
+++ b/modules_k/rr/api.h
@@ -69,10 +69,10 @@ typedef  int (*load_rr_f)( struct rr_binds* );
 
 /*!
 * \brief API bind function exported by the module - it will load the other functions
  * \param rr_binds record-route API export binding
  * \return 1
  */
-int load_rr( struct rr_binds * );
+int load_rr( struct rr_binds *rrb );
 
 
 /*!
@@ -69,10 +69,10 @@ typedef  int (*load_rr_f)( struct rr_binds* );
 /*!
 * \brief API bind function exported by the module - it will load the other functions
- * \param rr_binds record-route API export binding
+ * \param rrb record-route API export binding
  * \return 1
  */